# Routers

Routers are the packet-layer devices that form the backbone of the GÉANT 
network. They only require an active site subscription to be available, 
which is the location one is hosted at. Virtually all services depend on an 
active router subscription. As a result, this is one of the most fundamental 
subscription instances in GSO.

From a bird's-eye view, the process of deploying a new router in the network is as follows:

1. Manually configure the router such that it is reachable from out-of-band (OOB).
2. Upgrade the router to the most recent OS.
3. Deploy base configuration.
4. Configure trunks to connect the router to the network.
5. Update the protocol meshes (such as iBGP).
6. Promote the router to the production environment.

![Provisioning a router in WFO](../../assets/images/WFO_deploy_router.png)

*WFO provisions a new router by following the steps shown here.*

## Modelling and attributes

The attributes of a router are as follows:

| Attribute name           | Attribute type | Description                                                                                             |
|--------------------------|----------------|---------------------------------------------------------------------------------------------------------|
| `router_fqdn`            | `str`          | The FQDN of a router                                                                                    |
| `router_ts_port`         | `PortNumber`   | The port of the terminal server that this router is connected to.<br/>Used to offer out of band access. |
| `router_access_via_ts`   | `bool`         | Whether this router should be accessed through the terminal server, or through its loopback address.    |
| `router_lo_ipv4_address` | `IPv4Address`  | The IPv4 loopback address of a router.                                                                  |
| `router_lo_ipv6_address` | `IPv6Address`  | The IPv6 loopback address of a router.                                                                  |
| `router_lo_iso_address`  | `str`          | The ISO address of the router, used for ISIS support.                                                   |
| `router_role`            | `RouterRole`   | The role of the router, which can be P, PE, or AMT.                                                     |
| `router_site`            | `SiteBlock`    | The site that this router is located at.                                                                |
| `vendor`                 | `RouterVendor` | The vendor of a router, either Juniper or Nokia.                                                        |

## Deployment

For the deployment of a router, two workflows are required to be run. The 
first is creation of the router subscription itself, and preparing it for 
insertion into the network. After completing this workflow, it needs to get 
added to the iBGP mesh of existing routers in the network.

!!! tip
    The creation of a new router also requires an active site subscription, 
    ensure that this is already in place before continuing.
